@@ -46,9 +46,9 @@ impl<T: DeserializeOwned + Serialize + Send + Sync> InputType for Json<T> {
     }
 
     fn create_type_info(registry: &mut Registry) -> String {
-        registry.create_output_type::<Json<T>, _>(|_| MetaType::Scalar {
+        registry.create_input_type::<Json<T>, _>(|_| MetaType::Scalar {
             name: <Self as InputType>::type_name().to_string(),
-            description: None,
+            description: Some("A scalar that can represent any JSON value."),
             is_valid: |_| true,
             visible: None,
             specified_by_url: None,
@@ -77,7 +77,7 @@ impl<T: Serialize + Send + Sync> OutputType for Json<T> {
     fn create_type_info(registry: &mut Registry) -> String {
         registry.create_output_type::<Json<T>, _>(|_| MetaType::Scalar {
             name: <Self as OutputType>::type_name().to_string(),
-            description: None,
+            description: Some("A scalar that can represent any JSON value."),
             is_valid: |_| true,
             visible: None,
             specified_by_url: None,
@@ -101,9 +101,9 @@ impl InputType for serde_json::Value {
     }
 
     fn create_type_info(registry: &mut Registry) -> String {
-        registry.create_output_type::<serde_json::Value, _>(|_| MetaType::Scalar {
+        registry.create_input_type::<serde_json::Value, _>(|_| MetaType::Scalar {
             name: <Self as InputType>::type_name().to_string(),
-            description: None,
+            description: Some("A scalar that can represent any JSON value."),
             is_valid: |_| true,
             visible: None,
             specified_by_url: None,
@@ -132,7 +132,7 @@ impl OutputType for serde_json::Value {
     fn create_type_info(registry: &mut Registry) -> String {
         registry.create_output_type::<serde_json::Value, _>(|_| MetaType::Scalar {
             name: <Self as OutputType>::type_name().to_string(),
-            description: None,
+            description: Some("A scalar that can represent any JSON value."),
             is_valid: |_| true,
             visible: None,
             specified_by_url: None,
